/**
 *	@file FaviconFile.h
 *	@brief file in header, generated from 'data\favicon.ico'
 *		using BWT / RLE / Huff / BASE64 pipe
 *	@date 2010-02-15 03:35:12
 *	@author FileToHeader (built Dec 10 2013)
 */

#pragma once
#ifndef __DATA_FAVICON_ICO_INCLUDED
#define __DATA_FAVICON_ICO_INCLUDED

/**
 *	@brief file in header, generated from 'data\favicon.ico'
 */
class CFaviconFile {
public:
	/**
	 *	@brief gets size of the data
	 *	@return Returns size of the data, in bytes, not including the terminating zero.
	 */
	static inline size_t n_Size()
	{
		return 21630;
	}

	/**
	 *	@brief determines whether the stored string is dynamically allocated
	 *	@return Returns true if the caller of p_Data() needs to free the memory.
	 */
	static inline bool b_Dynamic()
	{
		return true;
	}

	/**
	 *	@brief gets CRC32
	 *	@return Returns CRC32, or zero in case the data was modified (CRC not available).
	 */
	static inline uint32_t n_CRC32()
	{
		return 0xa2528177;
	}

	/**
	 *	@brief gets data
	 *
	 *	@return Returns data of the file on success, 0 on failure (not enough memory).
	 *
	 *	@note The data (although may be binary), is additionally null terminated to make
	 *		it easier to use (the terminating null is not counted in n_Size()).
	 *	@note See also b_Dynamic().
	 */
	static inline char *p_Data()
	{
		const char *p_s_base64 = "AAAAAAAAAAABAAAAAgAAAAMAAAADAAAAFgAAADMAAABQAAAASgAAABQAAAAAAAAAA"
			"AAAAAAAAAAAAAAAAAAAAAABAgMFBAYHCQgPCg0LDgwSExUXEBEUGhYZGB4bIyscHSgfJyEiJi4zJCwtJSkwLyo"
			"0TTUgQEM6PTI/TP48Nlw7PjlZN0tKSUZSQkFjSEQxW0ddgVFFTlNlXmJmWodPUDhWcXBVZHRsVGlYeV94YGdoV"
			"2tvf4KVd2Ftcnb/c2qEhm6OkH2Kkq+ytZR7fIWwtICXoKOmfpZ1mrack4z4iY2kep6PsZu/n/25oqWR68OYmaq"
			"pvcTFxsfyuM6hg6ezqM/J4b76wp2survB5czQ1tvR1+/swOPkzber/PTu2N/L6d2I5+iLyLzc+a3S7dX11NPK9"
			"vfm6uLw2a773uDz8do5AutB3ZbAbAbAbAawH5xfCGWKILk8B0ROgc6WADdFKg8qVmDqiqQygEG5U4OaLcA25bA"
			"bASIOEWgB1xVINwTAZYkg8JsD0hdgDyhUgWZFDLzAcEuxC0gUwS4NJbAbAYcHSlkgcIrwG3KKD1hdwFR5E9+Da"
			"E2BkXehpHBDEk2B74pQHLE6B6kqkG4K0B74owOYJqGVKQpChA+mWMBrFKA5IqAGZJC3mAE6BvCXB1ZJB1BSYMi"
			"zoO1LugciUqD25Pgc+XXBlQkLIu8B4BJBvC9sHgFsQaxTIcSZAXcY5wHki1AOqLGA8kS4PGk6DSyICIUYHHJ2G"
			"89PHaEP8k1B3BSoOSKOGTBClLQAzLVA6ktaDmSmQeaJsDQTsHDLvAbktgHgOOU8Dhk6CqCGa4OrKKGjUgLIskD"
			"qS7oHOFCB2pdIHJk+BkTMH55SYObJgLRUtkNQb0ngNmTwHOlSA45Owd0TAac0gl6eRByBdcFml3Jodg0EwDoSm"
			"QZk8B+oSQeKLOg6AnQOCTUG7JsD68kg8eTYLIL/pNgbcmAqD3pyYPHEzBtyhA6IutBzhYkHIk1BwySDdFGBui6"
			"YOuJgHTEwDxhMwcMowPak8BsipAdoViFYLQ3YPDE+B1ROgbcpENOAQFIUYPffIcwgLIooP2Skws5AJ8Dni54Uq"
			"eNcLRSQWqDS8IB4UoDWLEA0lSA7oqcGomA5zHNMPSA7okg8oSQcMsEHIE1BpJ4DqifBWksDow90RCmkzEsTwNJ"
			"QgGCkQydkMeTAVNe8bAOpKdB6coQWYAKVBwi8sG6KkBzxSIOAUqGkAgDJ8AlgAkhaxAJqDwCYBuyxIcKAIWZa0"
			"HPlKA5QmwDCSUIpOwtnixpYAf6sgIPwGGJA2oovCA/MDEAIFaAoBQBgdkAqzBvStQZFFB1RLg3hJDTGEA5JIOl"
			"JmHDyhMAifA9aUiFRQUYH0CYBoJgLMwCSG+BojAzzQ1wbsnYOxJqDiEwFtoTgpQN5kEFAE1DiqGcBsFhBbYAF5"
			"YPKlMg7EnwOrJmDjFOBlQlAfmkHaFKg2ZSgZMyDknYVCoTahvb3BhYpwkhpIrhcIhBoggGpMwaxYIE6wFsUATA"
			"N+h8D05PAdAVSIKQFwFgEZ0pEOJuUMByTwHhiZhwuA7ANgHlSag7sp0H2JJC2GKWJIOlKUDTWkA6J8DxJJDK9I"
			"asowWUAUiFSyTlQeXJIb2pAJALtgs0AKgDRFtPAjYQ6B2JNg0pizhNySDpSeBU6CXBwidg2xTwO7JgHjSZg6sl"
			"waxNQesJcHuCihWY8Y3Qe40gMeQfE7CszYmkGZPAtOlsSYER6U6BYGH5ASQBRwtTgFGC2RJ4TAWSVQSQ9wAFwP"
			"JzCkg8yS4NqTAb9mSwBXxLhzjCEgBOgGwDZEwG94B6wFEh0IGqggGBQgGAboNCAxKkMwszAJIOuJ8FqAoJSYWX"
			"AZOwDwQduWIC1GBXMxErgJECjArgEgLUgVpWp1YcsgGwBAHoBAMBkAyAQAsTAO/JIWpS0JQgd8U6DQTAOOUIOW"
			"QBAEASQtCeVSJUHHJqHuUkjyBBy2N8DIpkKsMQbMP4QGeIGBLk7CpisN4HEMCAAa4W2oBNRIXJCTKnIC8IBcmw"
			"aZwhOShthDdgPADAWAKEDakwHr8htyCIRrho4KsypsMBzQgEA0AQuDnydgKeB6QIBQBsxEzAEMAwPQAZgGwINU"
			"WWAz4CQFmAFMByQEwBNgIdAImQ4IAgC0Yb+K5PxiuGZtgd+UoDelgBaOASQ4jpMTqTXDLoEOATAgsuKYMrLeni"
			"9CaR2kuUadMIIej3HCf/EkeboT5vwd635Wi9j8GUnoeR3zzVOO3uCieza7b6v3fC8uKRzTvdMtWTXJmg/8Pl9L"
			"XUUk+4V8J3j4yVTRD8rCXfd3JPAs1LgEkQK4oxAdwQHPlduhIgem26ee7FO97Dq3+DqXC7AovS7oAwMlsnYCOJ"
			"wzGsID9/2chEySR4mFcdyUBVnjJLqeFJ8zz/0uf7dXZDH6NmOrkTw86YGN+T/aBlf3wtArfEOhLH12/mUYf9xg"
			"TftGKYsZmaPD5yxzskyxuS5UMmtrovuzc/gaCXlVy9Cs03ZbTnvxRMDfevTJbA94SQyxBam1NmLuk8IwEASQGi"
			"RObAxTkGOCfDnMRjuC4W/DbUyGYr8YXXxuz2T9efXvIejJGfIIKqZHNgugS418qXokDIDrdKeO0p0Wu11IoVRA"
			"1tCM13fwya7R3hmun6sHWbs7x4tEcZajk89/ZmtvCGdJcLZjcfIhIPtiSNz0fsX9jt08LFp4G9Tl6IxPURu7qr"
			"2UovJrvsmcu/tsj8H6cFfTmbCJWv9dG7r6fQf03+WqUaLO+Ne1UnD1jsDIZM5MVs6QH5xDvps401+aBdLmKtrr"
			"sirNlr7bDo7nVvsTksxuqetsHOGhfV5ngSGMnFqeSbzYnpilt4Gm4pjI9hqkbu2xn4/clta+5yesS/7Km+tmnN"
			"4Zej8TRdXqsqXFg+vLFeA7nbujbtJWrWzN1l8jsuA9xJAcTj9/8vZOEgZIAkhxmiTaHliSLfxi9T9bW/h7Ls1x"
			"O5+j/lg3ybCsX/LyIkSNj3n8WmFZmP5ezPO0g2pOgysFzikkQKq7MdoXMKjxO1taZKQtXbnNIZiuW7Xm+CoD48"
			"259/Ab9wuInsmPcL1vDzL7uv2Yn6GTYSWhIZogKnCoq/odyvCqthY6alapHmr9ZbciW6naL02Wzb/Iyaf8z7IQ"
			"iA4RD1HMCW9ieyeZY6CrvNSmMqGcIscQ2hFmdajeyWTxUv3Gq0oxLfdtv2lO4lrpNqjES3gWTHeSX+Oli03uy/"
			"g9ksQaNIvJhloFjd9mm8U0ll1xzPbcWilPCj+xA2u8aeU1qMtN8eydt7Sz41rx7WFkPtu/644L6y8ygyL0f/+a"
			"8xLNNRJ/r6egk9D4zTuXOOmu092j2j7X1D/7Vaih65PrJSJubs8a0kkgSBb3D7jz1Zfl7XcXsDfrris5hZYt/H"
			"1eK281T5BkBiUfQjNfjEc48/w2ZyvjS+RYoJ7o43NvZELbMAmYWIAnYWIAkjNbQAhiYB/MnGYGc1rWPuLb5+ta"
			"OANC2ksb6ulgR7p7W7JNO1w9Nhvt/bj2/zXFHqsZLz/c2VzIbF0kTGktuJpMxsoe5aY9oBSUR+/mPz2/mpoyeB"
			"W7+c2BX5DKGP3dcem7v+X8dj4NZdf9v2ENAHXy9m5dplBSnmi23r5Gi81K4nnR9h/o2YZZRb8+yU7CvyUcmGRM"
			"7Q0MBYgCih6QBAehemwFkAEwATAWIAkg/wKTCkYRpC0w4NajDn0v86EDxq8/mWZg0E2CyyutRKg8iSQ4QCAIkh"
			"wRAKM2occ0gr9PXQkNEkAsaREw+GUGCVL9TulD1C4xJFbZrnspfUftVqssa/zfs+v/Dtb+pBlpjA8RNm2ki76k"
			"+7u/2rLBpGP/HXNuKyZf7/Z7ve+a4W9BkH3i/d6vIl+6dv/I4X1e37MXHyHM/He+19XlLJifD6W06+R8fNz/Ph"
			"ezyvn+35/wu3ttUr/V0sb9GLAq/l4/7PC839zHi9x2Xz81HvLTHbYUmzEt2k1eoA9nDmBTkAug2A9+OEYHcgGk"
			"TWSFURdTXzSlLgVqAO1QuIJglAjAMGkSByRgyQVyRoAJIMqZIznyq4uoSyoOSt9yfwR/4gEAEBSEAYwXSAEEGf"
			"FcKxCUiS9UmZAawnCxyRCvIBrbG1ETMEPYx505LEBisfsUMBpyCHk2ZpEH5S6hUZcgu3JqTAobWrP0izpfu/y2"
			"/4oDPI5vw/J/KWXag+WTYQ9wQF5QmBt6P+qFxIbCyxJAWU3GKqQMqyZhawAJIfoAqy2oQsCSHpFTGbIjNcJMwS"
			"T5xca8QQUBovzMMBPfy3LUI5BYAtYfAJtnDEiQ8guxLcFdEGnWLVLrDLaksk8kkDwuhpUY/R3SJvtTmS6+Y/BD"
			"YOORe8zqe94KzYLaACZYDfRWqU0q2AaSzdoSgDMI6xFV1tSa4mSIMsujXqMgRBTRYdkVth/W7Vceis0zP0fwWU"
			"Lw0iY3RYPSwVrQnTrSI5JZ3iH7djkc5pmFkiszZD9jk2xSdO2R6pcRqOz8aGmJA2ELlJHfFSa4+kQmfPNIxXma"
			"LE6mRoqQvDKXVJ6Llza0+S6NOi9nJAnJAEC4DWkwcqukeku4aIM+jvU7ogO9S5yDtI/4Xk/pSI7WoMMF4sDy0D"
			"uC0jMx3ZBORNy8yH8v+pvaITXz39B9jZ1INJUI18cwFhtFgEFBIKBUIDL3koahSiCScrKQ0w+MUkguVKPfIbHa"
			"qkM0msIBtQGkOffKc0no/BIJ/MmBLd9Us0AfWQ73MmMuQMkhzWEB/Qh5f6GkUuOIYyRMTxeaChWAgIbDXvsHHz"
			"SHCZewSgEL+/8BU24NqyxSAE1e6R2vadNHP+mMgOH2gJ58ndIven/5bwxp+jfMMmrAlu/w3fadv7LuoZf7/oeK"
			"1ExUViWAK9gOZGcmjUA2kkthWy50CZwRvqvlhRkuuX/i5/zYpnolxn2Z8A2rRU6g99Kd7tsDzlsy/Mdg4kNb8y"
			"fbkPeyavQIPHny49QyfVPD72NitfLCkoRYRzwGy2MWQimXRIEDlwSeeme9QlE8lvP+3wktP/ueZ5b2aG6e55M9"
			"k/y+Nk69bj/Blqbd6f5HDzvOVu7vyvHj7CYwMU4s3x+Ze+Xioo3K1GXThdM7tdJTZ5Qo9OnjIGzSukHZnTluSB"
			"FUBNEaCIcdXXo4dQbZK6KF8YF0X2LPkCGTMENWTYNGhAIJqFLPjahkvVnkSSD8EkiXWKGQ23W6mi0M0sB4MA6O"
			"RNcP6vUG3f26APKJsK3elmSFkWwIDr+jNc0ZnZLSbOfXm0kCD8rYLXX7UoYCxfyZYxQE5PYuoUOHtudtcDdLN/"
			"IMd2a393rendYdjfdlW6hNf2/v9FrdNeJJNo+IzXX4iZvsO1R0ou/RkioMxaImCZF05WmlQpAmULkg60ldq0E+"
			"ThwWRYO8l/gx2VyNo/jNN4U9Iq8BTnSWeIVm3kr9ivp/qm/uNOsPv/tM3Aeart66GqaHbf8cUNDKFIClm8zftX"
			"DQBdCDazCIat7QHVl8LSmk9hmfO48tadHvcLzv2Nax/lrswEDkmBBs8WyEauixlyUUiRpJBAXjaVaV7VaIVQ4M"
			"B8S4cNUGD7Y0iW7EvgZGBiMIxvmZgfqSQsrI75DYdTW9g/RHLG15ys6Y24IeoXAyBj3gQBSMU6WxkVhLGnI2s1"
			"F73DybdsGnE1H35DkA910b9jxGe/eblPA4fmHd1np4amzbAHkEwKqQAqAJ4DICmeS4F9nmAOyUAaRWlKvCRxo8"
			"ldyITz+F6iB2eTfImvX1WLps2sKN3X9hdZTmn6/x7xp08xmUFtaHf1ifo9jKecpbtYO8SvYH3GfVkJxtM7acnb"
			"j8lgORw6OdVfudD/qgYW+z9/N53+PrW8QiW9lPeL5+WofTaLu1Vk8kDZzOGt7HQYy30VbJNDuVC4adYS1xWf+U"
			"oBYnnPlkCzIDvKA6AgOwn9ujYTDhHyFKkHfD2aBNl2RD00yiBJZrDo/Uv2cug5ih/xqYfZubEO/IkmU8PkRLRi"
			"iMmWVkZe6nvVl2NFw1+C3bszbWCt8SQGuvn625q/f4mq913h41Xy1vd9/QzGmwO17eZ3XArIk5ruBQMUWHn5DU"
			"z/d4E+0m1xJLgaDVrDWDFC1xNIvQNVlwy/35WaSoYrMdv2qs7/2imr3N066OH9rZQqOaYVtPi0agJa+099O+gs"
			"JEbpUrJP5XZOGGkvmMM1yD7fam+/LK6hxEs/1aWfdbvyblih4dzN29cfdznuN6eY5+d7nxf7TQnIdQgIMwMuU1"
			"TQzl6k6C8j8LoNZgNBNkwJr5yCMA74gP9egYGlJ0S48DmEJJe/9LU4Tde0K0LPGYtC/iW1ICdp9nUTWra5xEi/"
			"5su4KRI92iTDLpplv+LYhQi+o36yH+/lT6v30xYbs3G5z85Gs9Rcddl9rV3I9jy4rPS4cxfEs4jIYGO4fd7++n"
			"AsVziWU1oj/HcnX8jiNLeit1xbVx9+nMoxXSNy5ZbpvY9uw4rGgjkuPCpnh/NluLxLre+rkqJ4uppYgeIXflRW"
			"dVQWAuoK1uvZusMG2pxE1jqug+Kg5hxyCOMYySoFB8U33jcahbtyxXAMYtC2bmJAbqdOlz21FHuTkLc5xgyAXl"
			"6KOpLYmTp/OrZ3LGAuWljukj8pwlNgXUQ0ujdQdXVa5L/Gn4v09J7DbtCc+lTzAGuoTAwlT9ZiJWjUaI4SnpMc"
			"RYCYyTIyr0mhowQJkd0Wz+y6Q9y8+j7y9MgJGLfeUq4KTITUoa5DszlENhspshT4tzyiVCGvWxUvGXpWR5Mywk"
			"IAImluaiwiaMswiUBbT5XKLn+x8NuaRWuprjuVATZMtLnNnLJ1cCKFnVIjF+m3fY6RXftbN1J/00mUj4u9Ym/5"
			"0b+SLnwJe6qaamq2r+cFKjEFzs9y87qtczR92iks8BNROfCE1DnUMrba8Vtm1LeIiJETIPYAa6+ILhS5Y9l0VS"
			"s2U592igvbz+bUZwYEgfIPEIAhypXUlJ5SQXL6zHr22sR8LJzYWDUCmvwO4AQkOO+AxQBrhpak0AcMCtsD+iJa"
			"ykuabHi7+gvnAtyRuKvct1YeiX733O/fKk5SpEpJVCx11nkpC14shPePUXUwyk6BnM4X4w5tUnCudtcv5HWNQx"
			"YScioRIFIuquetkF4RsELWMYMgGRsuF8qarhOuAz/e/hNmbOTO4T1zcGVayoms/Ea1ZfEvJkGIFw3kZR8dnld3"
			"2vzsNfP0O+c4bB2WupZCTdPDvJz1sRvMLto/RgtZoBs/jouPAN2XaO5ajERKJrUrqGrI5evXxFBLOBbsqUY8l0"
			"NsirNIB86DyvbTChwRbbUeIzlqdvt/PDeLkplz6mjmy8d1oAHDArTnqWYU2sG8HY5JphX4YEkZ0loYoRQ3N3I+"
			"RjGvThy4Lj/hZ7yX858BIxX8hbIdVKaWRiykRxEVLN4lt3/xLtL9m29NuzljsSjTVEhipPFysgHt8+B3l8TNzT"
			"ofEgbmEkp0c40j3eObhoY/mVbXFrt8cHbqXWdiHd8ybUNJYnMNXshITapxfGFJrZPus5En8//LPdroXD3RwBk5"
			"zK9t3YfvC00A9oxPzFVL1xpZqJHSwO+b5QuRa23QgRdBySfZ+Qtu6a4uP3ruYCd3HdjztantFZdnEK5ktNkDoL"
			"eoybUps60qc3/XXDNVO5UgeFAP6y+gvAIdlrzx3iHYSjnJQhFerTLyLL6xOcxuqi0vgOR7DPy+fOswFgMStBsp"
			"2FxGWRIr46dpCrmoC5LNvDkOs9yp76p3jSHMNcU4U7nTk0TPrVk8pmWDC8qOMFKsnI4LtuNcymCuMh8fVhtXdR"
			"/lXCjt/J7zLrRujjnxuNDE0stM0Tp8huibRheGtEYczOFSw4JNdtgPresWXFz25AXBSl2cg+yxdsTmGa261iJU"
			"h3yYUxe8tQ2S8BJSAIB6DAmCAMlxSvVGCBAFqFGEESRAMGRmQBkDJIcmTIkIIgSTcIIytDUkSCCIwZkCBDyyai"
			"BLMMOlAIWOKYNIkEsjQAQBGRIQwJY2oTWX3h75OfZBDIw0JIrSIzbUKghQckgCiIBVIugIBPzMikkGFyCi9Mgd"
			"D7jmYn3O0wLNGLonNS52P8NBfUTP/WG9rA0cTuIMUjmb7ymSsZgr56AEi6xB4szIzz3e2rhWCa/YbmFAiFl1m7"
			"QmDQGhtyFaUSJKM6/VwZmAc4fgdjJxeuvLMNWKBF2v6ExCXyQHnyv7mVuQ2xUZZ8gK9xhUUG2gH0J/WBpAhQ0Z"
			"Bk+qtdChTMovov6+D4n8O/rhWE6twIHZgWWapRbScATdVhfwyuXu17CnuZEDXfItt6/sHwysXW+PWxJGf18Cev"
			"beem3srXRtxBqcTUOCWLRxKFbGke2oqZV+5n+gxUJU7oFeFPQ309wTh6LZwkOKk35DVkHbeaiyLP3nHBWxOUfQ"
			"hiW8BUCdmMYqFqOL6O7k89WZ7PPfV9fY92+D1XXZ5QEV+sgy4TRMRnVM+ZW5R9wNKctOUtAqBt6FBLCA9paESy"
			"K+XlGh3o1lHG2b0cVmxZ6ag6rrmAObggLg8ogUq1DTtbSTgAvvjRZO7ndXSts6S1MbJvcur/gYhfSxsr5CmW8J"
			"/HqtIs5mTOKK8s8BoZClAX7+XKuO0pDxqFisjI52cZrSIlvvQydOUOKwf1ycs6+xo+JgKAQ5hmEk/WQhZgAkiS"
			"SWmhAdgAhhcgm1ogGyyRWw9NdsBwlov5qbhOZyqlhs0mEGyIhonQFRJ9M86qyLLR/p2K6N66AocmlgCzqmM/Rr"
			"AiFhV59gYaZWfGbIiWI6lzR41q2VGPgU8CxseZT1idRfcHg5jYeU2Gt63g5rTd9GdaCcB/pPu8khPy5Myebb28"
			"RQDQN91QSOCRzFPMPn8oJF9OIiZ+kUrj6Tye3veisHVurzWkB5VUj/IWJXYhVNjjg2iBwykSnpNop3qqIb/9tX"
			"LVNWGOwaf6ZisRc4W5/7Sy1eC1zDHCipvVNuraN83vCYXvdGcEEkVvJJ05Zua5fL47NbfnMXNNMZuA9eZ/F4Ea"
			"BcQIEenjqw2gbz22cSa8SGMjKq1ahryG0zUpf4qFKJlVjWUWgcZwq+vWF9DGwLgaN49UVPLbpx+/keAtjHDJtq"
			"8KIvVRoT5WcdUy2Vne/7LIH7z5COcjriAycGgnnIvpLKWbIMiSMntxhYyz3nj0Wua1FtLaPB7tEIuZbLVeQcOJ"
			"LEyFcyVqc4cGy9tAbJLqYudFhMwe/QhbQX8vs6HdPfc/b6vx0UOWc8/X0hKLttW+zrqwms0pk2gOECSVKqi5iZ"
			"az3t5zY41lyUVlvMOphhD6sfyNsDm47xeenniYlbjaqVn6d7FdlfzVuizyE2j2iHrE2hMEBQ4cHUQctGvXbYBo"
			"NSAwRlCLNbFqtJmhdSzdG1Ucr9/Dj+5KrrsHzmAKbfKrn4dzUZ3BP0evncboeLHtqmYr7S37SEdEngOtGzA/ez"
			"0HY27jG2WV2KvEFIV2S1B5en9HV0dAqrRUxKHaZrCdQCy6w/KqMVB8NEB3tU9VCczYSKn+aWya9DoFfxICv2zX"
			"s7iSgaXKZW3WonGUpsqzq8fH0kzsv78vlxuwLSkzsradBFkjBEbUPcMBwEIJRsBR7Q1xW6VQU0OOjpURtvW7e+"
			"o6Ka2Mp1Efa220IGp9fZiBvyEUT0uZH/67eIhgkFaFaZt9GHOy0Nafkphpbk5pnWIpn+VP5NMxvdduMfKzuWuv"
			"Ot84/moSzfOP3NPBp+8vZ/WQZPhSaArDnXjMnMVN6/wfaiPfRrcoibJ0L1aMt227eRbVemmqDQmLygtYOtkeVL"
			"tXkpE1rAC3pHIdt2MOQ3FpY3+fpIcNr5eGf7STzOfmHOVKDjqFF+3mpekQjV8vIvkvSHbzVLJzot3uQ891vNbN"
			"cyy/Z11jYEV/GnIOSyipPEVywFla3pSM5ultD7xeP5mUaN+NusG8IgQuOxn1KGDdZ3XZrLtMXp76FiXgFT8pXR"
			"CD2tigf04Bi9Jiq0xzwU2BsE7BkTMMliBkkOSqJL/a/45T12cukVuM9l/ii+/R1czq0AV8eyhlJd10Oq1e1dkE"
			"eDMnXM7R6bMM3s0y0bGxEtQyu9qjFhUXfrTzLlkNRQOn5NgK31TZfdFnsu1ufn7pg9jEQzf2qPggOd5fPW48fj"
			"YLRqXoZY2exe59SpCflaeUnw30qzV+WIrYP76BRSAwIMZ0AzC5+6Xe239kY/Fahqp05lGp/D8Po7IS0eNd5zrc"
			"s2jE9Ak29VTJ7TProlufYpdRlgN2GWv4lxHn8MXk2GyeXD109oOh4st7WY8GX0eQ0+H5M75OnOI5Vv5RVPkaL5"
			"lYebEAQPpXlikGQrZptfmh2XUJ/BJslqzIO5toLZpfvuM8buD4eXFMNY0o+HuUUU/WM06C0Xw9lxZKkT33x60P"
			"NXI9xr4Gqx+lZ5HMKU5leg52NtM0VZHvhGtmMjmM5WKFTuBlZ3iDnUfU3P33+dsNPJHSYf8MYqDLS0l0ZeXkt7"
			"X1szE0tBjc20AVXup1R4vk8Z6FSfUqwdoct23sS303+vfRZGxwTG+61z1fJo3LqryNcGmTmos/LhuGfb+28waa"
			"SyHWYGhErStZU5ugp40bH4PMaX+8KRrNVUO8lxL7/7il5PBe5tnYYE11kOjU9PK123PS0k+Wp8xjnSXnxs9gcG"
			"ccptanaMnGOafb2WckXXiLB/oIIsrmdWUNm97Gnzg9rPWMWY1KOFUMizU3bWqKaLhLsm5m8Q0Uok2GX0igEkkV"
			"vx9oYxMkR/TYmh2Z5B3L2mHTkSBK/rpM6+n6Z7o8K55M++jXDe61H1SvHeuMHTTFJd2tcetg1WpiaaZsYVwlFk"
			"QIpHP9w7cPGvYWg7dh1bfTe8rT6R2/vJR3i8Prx/RU1bz7kFj87yMCNdKe6bfQW2Ioc9QZdPWVRbF981ji6UZi"
			"VdwRKk8spEBuVgXg+JhWypa6AMCDQ5/+BYqF3i2YZWT8cvEx4cv/H2m+dA78B+B2fkUlg5oXQCGDYC35AEzE+Y"
			"CQPHAIDIKAUB9MEwEMBz/QEgAsl7+UYEHLqGzJADIZNC4hsyvNyawHQXAQwDXJI2US7l774U+V4kfOiWTL1+/o"
			"BsXHdLxooiYpvc5UwOntKeyo3Jfdi7XWrZ/4XV59nKezFqkVtl6p5uPSNrYs3Xy/X+Onm+5LM+8Gqy3md6tJDA"
			"KPo/qpdLKE71SODe6f7qO602Pxld8EN9kG1XjuRlHayXU3xJ3Rc2n1sSZe/jKh4lu64dBH04zpPJfqY+p43YQ+"
			"4ISxDtyxV4cWqnavdkItJm8HjUB/z4oCdrY3HfYiunx2FBUSv9oDOarGrwvHIUCp7Gc+syjSm27t3pwNu+DMBz"
			"jfMaSQ4sZeZYg2c91sdT6WGdZNfcaGXhzhjZ+YYw63iXWQb1fHervdXSqGKTrOsMb2hmFxjfr27dxMYtvkJuzo"
			"v50OT8HbddvNuVCJb47HNOYtNGRGOW+2ssP/6Og+B292wz+/NI3L/FYiXnXLkC1vPRf/z+ubHacjne3Z3EDsZ3"
			"Bu4GuuzFP2nr27WQgD0BjusoAwQmUW2ac4606g6XlzDFRDGImNzmEitLCmIdp1nm/0+KcxDt2zsB3M+Uk8/h4c"
			"L4nVzKCr5Eh4bj3y771mndcfNsmdIyyeKjqPUDxXor9RdPSePEV8LlWokO86/UbSxlZqvE0Qh18QqDuWdI7ycO"
			"FD8xqB4PyH/jDuLLypjZ4qGD30fcy7qCh1mG+PrsCk0Nb3HzQX/GL1V1nw5blyQZ9lEySODZ5OhxeLr7SDgrZx"
			"55CzLR/rKv9+HPclvHx6mWsdHLgoGLEpNwRwSG549MSOpkq6DPY6FZKpoew+q47EPLCPUvBffaPdQBrHOfKSf6"
			"mXx8FTzHckPdNVfQCBWD5CO7qvppgzFM1waPIUr2l5GNnLPLWqBdIO8JcK5/CUkZz+GQ25TuPmYRBUad/EdCKx"
			"IgWn5cVEgLcdjYearo0V3QlIEICkiyryHyxncD14V2VJxJL0Xk5rZw4OU66u3+RwXgFcTArSLM2G911h47nRTP"
			"BEfyMdvKxnvC5zn+U4tnlkhYOyASYRxF9XpPd7h1Hoy7zyeNznnfUOo5VdKvJfHWKIe8QUE2XVioBLgEwWxIRk"
			"KAwp5TXf0djIyAiAt4Oo2rJzw5Xm2g7uTmfnq7KjqLeZIPe7k5AqyXwreAwJ/Hwraffel+1vKTDmr8f6qN3VtC"
			"XxOMm4Lt2KL6yOC71Ev52aor/+9Hn927C0Czzeyr3QfEkXzvw3Xi1XDopfm9ns2d9fvxQju/gm5yhSAtnDPMF7"
			"FhRX0VcLTeYBriqzc5cLhCpC76ROCFyUji9JV+TiU5yuv0hz3MW8KW1453bO0hVWCSK2KWFAOZx/nPHkEfsnXY"
			"dFPBE9U0Lwnnk62ocv34OD+tjhfR11Th/19rLaHLWUK9qIn9zFvIhVNpJGzx03IRykRIlyx9Y21o+qWaNJJUKy"
			"UUKNuv+aAIrKKddl+wwpgQTJ3BGJJC5ziAYuZ9lIResE5WaNGJ63Je159DEofHgARrS98yKIcMcXLutfi/endF"
			"U9GbixpgxMAd7MTioTZ0/d7tEH8HlzPQtpqaryN2VPyZLPWc8fpyjyZeJFaT6x0mweuJSpI3vadBTpKeKoH/nK"
			"95tsPpn+J0slKFqhtIWqudjFcSUlKeMRVFVFqKikwzqoJ2CKkH97fZZrbY7F3vRmMdJPMhdyjp98CvBJmPNp7n"
			"UFtrwW7LnFir0Y99SislTFZWaDX5mhZ6PGodznEjXrFbWPZV9XGjdoc0dj2+Q3VcJPLRAIGM1kHn6nyLa51X8f"
			"AHxZfNw+tqbkVfuyy0/Cn2u+8/per0PYa7q957Gmj4Zm9Aw19ZuentbHJxLJ26MZnIR0l5aRtdVlmUHfu6kTQK"
			"yGZEu8HHEgJkV/jVCsrD6KBzVhlNCMpKXL8nMp+2XZcL2/XppR/wa6U8+sbBE3+qGxVoHrQOytexsZuch0tJ3n"
			"0bm18jfZuR0nsKdtsMhI27IIlGcz/VPK8h9r2JSLUvccjU8foyqvArHTLW8bxs2m1HjM0TIuHBdLY7v/Sr2cMc"
			"vkcL45eNk7qC70EEO/ZyLV7+ncvOv87w+lxerYUQow36mvmpTHXPfTTeX5QyenqcNjhqt9Fbb6Kz4XZVw4nZuM"
			"uWsOIJxVDnY+R2fMdly8nk2floSJfDY4zALTEF/p11zLJAWJIm1yCsMetJLQwMySFERgyaihMgFyBEAhBhBBGA"
			"pC47QiA8/Rqd+KEjGVAe3MjK6fI+/4UjEKrqLXhfuyGKc2+UnvKndWOk1ucMimKoYsv47ydxsGH22LER162pau"
			"qPD4YUHpxcG7vGYl7fKt2wFQwBaMBuQFb4Vp0MSuHC4BOvrvGA9l1N1gFAJdV1JaMgFxtzMAu4r5X/EpcFvWQG"
			"4tX/M49Pxkuq2C9zDJtEIf9q7rjSWVuc7BvB4UD9LCQnslqNVs6jzZ5u4Lwv5svvc2DdCNl2P+GnqTNTtYuM2c"
			"9I8ZXc12w6aJGZet582O48qvqMr1+WzOMOZbZ/l8nKqmQRCafbhXpavjXmddV68x/+vgDwzurzeXlXMNu0+KPZ"
			"tPatf9v63cV9MLrTxZH3KygfbmD0EfzECrla+Qc5amzfasOcXNa7wtgHkpDwqpnJdj5spMYwcmyO4KEJFxs2/0"
			"SH+m7rD722x3fzvc5/kiLb6ick+vo15ksHhcOsy1GjNVOBHibg4PvJH6eZkmeXddb08W1+8ZnEdsJz39sDQCWr"
			"d1hrYCxK7ZRIGSlbiI243C5QGgIN6Nw0KdPrm3fdOck851fA9Hka7pzbePp875NPl85INuskslip2hLtYbLUTM"
			"/yevmeOGGd/ZC/veNtVY2YpW8xkoMxjZtorED5O5rnUZYSWZbt6GJ1g6nscpMlPfHPZRoJmRpslJ+990Tf6ri+"
			"hrd/kOHKtxNNbR+3mZbdaHBZ8P0azzqWebtu1Zt0axvV7BrLrOuH+vK8qi9wVXnaNXXY2HbM6W00b6EO2nNNjc"
			"It0WOpHGhkJ/xex5Ij+1FhthVNrKb5PTZygrYoDkDU6UDtD3qAIgBAPWYatW10XCbCVuHuNS0DryWNLI561Hbb"
			"jlbZNo33Fce5ntE28Xr77tR9txmINu4bufO1Pzr+72bKUlMMsoLWSOTVZ3iPh2O2IY7H6aovbiYbuqRvODnNSD"
			"KCyeH4Gp1L+TrdqLEsvluyQ4xNQHmZA0tGT7Rd45spyVrrhw1lVxl33O6xpkb1Yutb7MZiWum9my2U1SzFO01c"
			"059TIwo77AjMxF2WGllQIzXD+hRu3ox+G3657rb9nbbOpaPIc1M9+J3RSr27l+LRYbcTtnhhKWUL7Cadb0UQNL"
			"jf4/i4vChW0DKFj6qFcm1JdihgqpwCA5oHfmA1A1TsNfQ8H9y0T1PDfgNliMiA7raGA/lnVJl8Hadz15BjCI+q"
			"9RZ/uTZGWdp1sRzuDvWBFhQYymwWSXZEwFTIbOxdJq6Tr2eIhTuaubWLUz/YY2I+V1fS61HBvFreJn6kVPs7uS"
			"8UBh7JmwIBECIyAjoMiXCiBJE2gpAzIo5KIUtWc2Xf7tk/ZJZh+u6j0i6SITxMDQz7q56zW5fYwHG0qNC4ur/n"
			"yyez0f5lnrS/bx/S0889e5+l62N8XHvGi2k01VKRH6FqOmOf/R0huYsIbA93FgUAGeA+99d5MZNq2ZAfwb/8ag"
			"JA5TByH4t8zgb6RlM5nbFuA4A9Sc13ZwE6T0+DNa6LoXnVgljrPgvZyU3HjY2Ph+A1xGsny3Gexp39vuLSSxJO"
			"YNz4wHg7u16TYSUeq3rYqASZAEwAswLC7AIBfC3H+ajMSU/weCC5rYBm3SzAoGOs2igJ5Qn5hx6bRCW7JgCyYG"
			"XZgLWz7kZRWBoKJC+Wi6fLTKfsJe9hru0gOq+aAOdxYeLCfCZWxMBnAAtvzUwFkAE7EgQCA7AMBABUYNgkgGwA"
			"VSFiAKKHuYmj9LKmLongf3mJ92MlIFGCSDMmYfmRkK8gNqSQe+JsKVRDLFmSAkyfYIDRCQbBJE3hdL+40ng7Nx"
			"Sb2YvFptarasyCpM3gkGZcstFpTD32UIbQjdBlUiZsUMwbsnwZM4fqyamAaibAaxKGAZEuHDQliBFKA0EwMVOR"
			"DpSlyA5pAT5JAnwCAjAGAYCANeAbArqoCkAWAbgGA0AMBQBgEAlcBhJYANgmwZEEINKFAmGAb4khSgSQ5ZlmgC"
			"AekuA0SS4ftCBoIwCJ4GUgQSTYBd2HpmFECJDsUqwBAEAZAIAN8DXJ4DXJINBPAaCfBUgTNgGS7AaEQJIST4Mt"
			"EQXJ2GiDMGTAMySHBED+qMhIWogCfA2xNg9bE8ILkyKUBmTsKIE1B48mYNBNgpGtNINBLh+0JmXeksk0kwG65J"
			"IBJOhDoCAWIBxIG2JgNFiDIzYBtCYDh8g0kZLhZuSCSD/uTANYowNJMAyKVEQyUTQmRAGQCCagzJIZJIKJ2IZk"
			"B4pECDl+bMPZQgF1nHRVCBoJgH65OgaSXBuiig3BNgbwnwcKIQyUTAaMyAZFpwb4lw0MgCKMDIkg3hJBoK9BoK"
			"VCjUbYGZMwZkwGjkkkyJINYpQGsTsMjIEU8DYJmDMsOAYA";
		return p_Call_Decompress(p_s_base64, 21630, 13973, 7793);
	}

protected:
	/**
	 *	@copydoc CFTHDecompressCode_4d0633d3::p_Decode_BWT_MTF_RLE_Huff_Base64
	 */
	static inline char *p_Call_Decompress(const char *p_s_base64,
		int n_data_size, int n_huff_stage_size, uint32_t n_bwt_primary_index);
};

#ifndef __FILE_TO_HEADER_DECOMPRESS_4D0633D3_INCLUDED
#define __FILE_TO_HEADER_DECOMPRESS_4D0633D3_INCLUDED

/**
 *	@brief decompression routine implementation
 *	@note While this allows all the compressed files to share decompressor implementation,
 *		it restricts all the files to be included in a single .cpp file, otherwise linking
 *		fails because of duplicate symbols (remove body of decompress function in such case).
 */
class CFTHDecompressCode_4d0633d3 {
public:
	/**
	 *	@brief decompression routine
	 *
	 *	@param[in] p_s_base64 is null-terminated string containing BASE-64 encoded compressed data
	 *	@param[in] n_data_size is size of the decompressed data
	 *	@param[in] n_huff_stage_size is size of the compressed data before Huffman encoding
	 *	@param[in] n_bwt_primary_index is primary index for the BWT algorithm
	 *
	 *	@return Returns pointer to the decompressed data on success, 0 on failure.
	 *
	 *	@note The data (although may be binary), is additionally null terminated.
	 */
	static uint8_t *p_Decode_BWT_MTF_RLE_Huff_Base64(const char *p_s_base64,
		int n_data_size, int n_huff_stage_size, uint32_t n_bwt_primary_index)
	{
		int n_base64_length = strlen(p_s_base64);
		int n_base64_out_size = (n_base64_length / 4) * 3 +
			max(int(n_base64_length % 4) - 1, 0);

		int n_prehuff_size = max(n_base64_out_size, n_data_size);
		int n_temp_buffer_size = max(n_prehuff_size + n_huff_stage_size,
			int(n_data_size * (1 + sizeof(uint32_t))));
		uint8_t *p_temp_buffer;
		if(!(p_temp_buffer = new(std::nothrow) uint8_t[n_temp_buffer_size]))
			return 0;;
		uint8_t *p_data;
		if(!(p_data = new(std::nothrow) uint8_t[n_data_size + 1])) {
			delete[] p_temp_buffer;
			return 0;
		}
		p_data[n_data_size] = 0; // !!

		{
			int p_ic_tab[256];
			for(int i = 0; i < 256; ++ i) {
				p_ic_tab[i] = (isalpha(i))? (i | 32) - 'a' + ((i < 'a')? 0 : 26) :
					(isdigit(i))? i - '0' + 52 : (i == '+')? 62 : 63;
			}
			uint8_t *p_src = (uint8_t*)p_s_base64, *p_dst = p_temp_buffer;
			for(const uint8_t *p_end = p_src + n_base64_length - 3; p_src < p_end; p_src += 4, p_dst += 3) {
				uint8_t p_tmp[] = {p_ic_tab[p_src[1]], p_ic_tab[p_src[2]]};
				*p_dst = (p_ic_tab[p_src[0]] << 2) | (p_tmp[0] >> 4);
				p_dst[1] = (p_tmp[0] << 4) | (p_tmp[1] >> 2);
				p_dst[2] = (p_tmp[1] << 6) | p_ic_tab[p_src[3]];
			}
			if(n_base64_length % 4 == 3) {
				uint8_t n_tmp = p_ic_tab[p_src[1]];
				*p_dst = (p_ic_tab[p_src[0]] << 2) | (n_tmp >> 4);
				p_dst[1] = (n_tmp << 4) | ((p_ic_tab[p_src[2]] >> 2) & 0xf); // fixed byte order
			} else if(n_base64_length % 4 == 2)
				*p_dst = (p_ic_tab[p_src[0]] << 2) | (p_ic_tab[p_src[1]] >> 4);
		}
		{
			const uint8_t *p_huff_src = p_temp_buffer, *p_huff_end = p_huff_src + n_base64_out_size;
			_ASSERTE(p_huff_src + 16 * sizeof(int32_t) <= p_huff_end);
			const int32_t *p_code_num = (const int32_t*)p_huff_src; p_huff_src += 16 * sizeof(int32_t);
			int p_min_code[16], p_max_code[16], p_table_off[16], n_code_num = 0;
			for(int i = 0, n_cw = 0; i < 16; ++ i, n_cw <<= 1) {
				p_min_code[i] = n_cw;
				p_max_code[i] = (n_cw += p_code_num[i]);
				p_table_off[i] = n_code_num - p_min_code[i];
				n_code_num += p_code_num[i];
			}
			_ASSERTE(p_huff_src + n_code_num <= p_huff_end);
			const uint8_t *p_symbol = p_huff_src; p_huff_src += n_code_num;
			uint8_t *p_huff_dest = p_temp_buffer + n_prehuff_size;
			for(int n_byte = 0, n_bit_num = 0, n_counter = n_huff_stage_size; n_counter --;) {
				for(int i = 0, n_code = 0;; ++ i) {
					_ASSERTE(i < 16);
					if(!(n_bit_num --)) {
						_ASSERTE(p_huff_src < p_huff_end);
						n_byte = *p_huff_src ++;
						n_bit_num = 7;
					}
					n_code = (n_code << 1) | ((n_byte >> 7) & 1);
					n_byte <<= 1;
					if(n_code >= p_min_code[i] && n_code < p_max_code[i]) {
						*p_huff_dest ++ = p_symbol[n_code + p_table_off[i]];
						break;
					}
				}
			}
		}
		{
			const uint8_t *p_rle_src = p_temp_buffer + n_prehuff_size,
				*p_src_end = p_rle_src + n_huff_stage_size;
			for(uint8_t *p_rle_dest = p_temp_buffer; p_rle_src != p_src_end;) {
				uint8_t n_code = *p_rle_src ++;
				bool b_compressed = n_code & 1;
				int n_run_length = (n_code >> 1) + 1;
				_ASSERTE(p_rle_src + ((b_compressed)? 1 : n_run_length) <= p_src_end);
				while(n_run_length --)
					*p_rle_dest ++ = (b_compressed)? *p_rle_src : *p_rle_src ++;
				if(b_compressed)
					++ p_rle_src;
			}
		}
		{
			uint8_t p_buckets[256];
			for(int i = 0; i < 256; ++ i)
				p_buckets[i] = (uint8_t)i;
			const uint8_t *p_src = p_temp_buffer, *p_end = p_temp_buffer + n_data_size;
			for(; p_src != p_end; ++ p_src) {
				uint8_t *p_dest = (uint8_t*)p_src, n_index = *p_src;
				*p_dest = p_buckets[n_index];
				if(n_index) {
					for(int i = n_index; i > 0; -- i)
						p_buckets[i] = p_buckets[i - 1];
					p_buckets[0] = *p_dest;
				}
			}
		}
		{
			uint32_t p_buckets[256] = {0}, n_sum = 0;
			uint32_t *p_index_list = (uint32_t*)(p_temp_buffer + n_data_size);
			const uint8_t *p_src = p_temp_buffer, *p_end = p_temp_buffer + n_data_size;
			for(uint32_t *p_dest_idx = p_index_list; p_src != p_end; ++ p_src, ++ p_dest_idx)
				*p_dest_idx = (++ p_buckets[*p_src]) - 1;
 			for(int i = 0; i < 256; ++ i) {
				uint32_t n_value = p_buckets[i];
				p_buckets[i] = n_sum;
				n_sum += n_value;
			}
			uint8_t *p_dest = p_data + n_data_size - 1, *p_begin_1 = p_data - 1;
			for(uint32_t i = n_bwt_primary_index; p_dest != p_begin_1; -- p_dest,
			   i = p_index_list[i] + p_buckets[p_temp_buffer[i]])
				*p_dest = p_temp_buffer[i];
		}

		delete[] p_temp_buffer;
		
		return p_data;
	}
};

#endif // __FILE_TO_HEADER_DECOMPRESS_4D0633D3_INCLUDED

inline char *CFaviconFile::p_Call_Decompress(const char *p_s_base64,
	int n_data_size, int n_huff_stage_size, uint32_t n_bwt_primary_index)
{
	return (char*)CFTHDecompressCode_4d0633d3::p_Decode_BWT_MTF_RLE_Huff_Base64(p_s_base64,
		n_data_size, n_huff_stage_size, n_bwt_primary_index);
}
// a dummy function that calls the decompressor, which is now declared
// (allows us to keep it at the end of the file)

#endif // __DATA_FAVICON_ICO_INCLUDED
