/**
 *	@file IndexFile.h
 *	@brief file in header, generated from 'data\index.html'
 *		using BWT / RLE / Huff / BASE64 pipe
 *	@date 2013-12-16 13:02:34
 *	@author FileToHeader (built Dec 10 2013)
 */

#pragma once
#ifndef __DATA_INDEX_HTML_INCLUDED
#define __DATA_INDEX_HTML_INCLUDED

/**
 *	@brief file in header, generated from 'data\index.html'
 */
class CIndexFile {
public:
	/**
	 *	@brief gets size of the data
	 *	@return Returns size of the data, in bytes, not including the terminating zero.
	 */
	static inline size_t n_Size()
	{
		return 5137;
	}

	/**
	 *	@brief determines whether the stored string is dynamically allocated
	 *	@return Returns true if the caller of p_Data() needs to free the memory.
	 */
	static inline bool b_Dynamic()
	{
		return true;
	}

	/**
	 *	@brief gets CRC32
	 *	@return Returns CRC32, or zero in case the data was modified (CRC not available).
	 */
	static inline uint32_t n_CRC32()
	{
		return 0x06f678ed;
	}

	/**
	 *	@brief gets data
	 *
	 *	@return Returns data of the file on success, 0 on failure (not enough memory).
	 *
	 *	@note The data (although may be binary), is additionally null terminated to make
	 *		it easier to use (the terminating null is not counted in n_Size()).
	 *	@note See also b_Dynamic().
	 */
	static inline char *p_Data()
	{
		const char *p_s_base64 = "AAAAAAEAAAABAAAAAgAAAAYAAAAJAAAACgAAAAgAAAAPAAAAFgAAAA8AAAARAAAAA"
			"gAAAAAAAAAAAAAAAAAAAAABAgUHAwYECQgLDQoODBAPExEVEhQbFx4YFiAcGh8iGSQhHSYjLTInMDErLCkzND4"
			"lKCouLzpvNj9ASkw8cXk1dj1DOHRaaHdqdUJ7W0ZrN21QflJwZl1yQURWXFVYc2xZYjtIZUVORznN0C7uGu5UC"
			"//8S/qvjWokh1Qb7E5gwg/enL/5oPL9/4xcx/H86/ROS+5WHJz9v0Ea/vkH/oIn4y6+WCIwOGCC9YKKQoEldhr"
			"oEdATgrATgtwL9wLrJoTgnBagW4+D/z0sWv9/0XfSs/kJrFSWJ+S+N4rVdYX8fz/x+sK8bCWsyW0a5eM8XQrbI"
			"9Axrxb+ZCqw/3Gqv0V/Cw/jGaIrO01H4afNMm7DBbtn13ZhiSgV6I9f5S1caS3dSsgYM/U1VHWX9sC62XyywXW"
			"GcC6fWQxeBxdFt58xKxQgYcC4yhfA6LiINgbzddPusPl5rHkJGGpuxTjfawfsW0xozcJXiUTinPa6k0crG8Etr"
			"FLYFI/fS09Vm65wiYBFjWNM4kzBx3JYTOiB//5688tDcUu/XnEN4gwBy8Mbc7JH0xC5LZcyDW2GRjpK2a5hqCP"
			"By+lrcFSyzC6FGxU4aXSOFbDTuKSpGXXla5OBZQP9tp68V/1O1LqLdFHCcTbb2kCFRYtF/1ufLPgwfh01sqbJ2"
			"KaLJSCxb8G7SA6kCgVmDYfaNau0b+StO9uYlrZCZ3q1tUScnvV7l/Rte7+WEebha54nsyDMMIa/8scRR6RxqHb"
			"GBXeCVBkqB/DaF3cSx6NH2m+Wrn0X9u2/GDsVpbae88psLr8O/Muf/DzSj+hRhdlRyei+mB57hg8yexzwnm/zb"
			"rD036vDAl4dUul1d2wTrzWFeS0i2omtTbi6rMubOThwbUfNu2sURzuD+vl/P095wga5rzk6OE1u5E+Y1Dq+GcL"
			"SuWvr3IM2DsgYdmPu7axaBNgdMKBgvQEp/BaGyw933Q39hqiTZDIsJMhUOCJqSiefwW9D2hVyULKTc2T8KVzBF"
			"M5ckIVDFhIEJyTgsx1gLX5wtclrPq49Zrj4EweAHc9UgizbmCIlNopxeRjFO5Jm8e+wv4flWLnUzmzaEiMEvDO"
			"B+xUp771QSKL0NUIhdJJiFOWFS7vTjQ2ULp1NSdzzoURIV5kRikF9IxoXJAlQ9e7+ge+vf5m34UXiM/xtX+sw+"
			"E8uhHCw2fZ8Mn9VkO0JOEbDh9EzE9m/Mj8Z4rD4OXjKo+EP2/X6HBkX9O01Bvx3nOw9san3KR/ozYhm390+sFY"
			"TvL3N6ocO4KhzYOdXK3rqWbrA3/0Yr02F7aWMfVD0bicT57BtGsJ7c7LA89Ds8326fxVbPkbpuO9Hg5vCB0N2e"
			"S/1npDyTG9UCtK6zY5xp5t8J3Ft1jWZGDU+IITcudEeA8cVytpPaFPYEMzW0SCL3ScE5y9Vtuty2wvjss+lbJu"
			"N/3GAfFQ3/O3THa/Kf6QfqBOSmba7jslnz+DRx3YRVB07My/1uGwm9o0p+wLLSSPnt1BdqKx0m3poNc0C7sQM3"
			"WNL0UJxNNRwunWZYcS+NE5XRITmyspRjNhZM53xGBAwiMyLtpNzFvE8ZJlCg0FQuoxem8JjjCDkAThpQL6GD+7"
			"Y6aMD3qWhiw0Tnqz5Gf6umXL26xtQSgYzIF0KeOcBsFYfIpnfErFBWBK5272qoytiNywup5bDntlSsLIx+zvvk"
			"Xs5XbJiDnReiiQa2LxsiTIlAbLRzY7Fz0IVbY5zgHpKhbXGMFJwvcl4W4ruL4J4jCoSUTOwr5Y6SaBLIi0Ao43"
			"Vi5rYJfWaghQIupwW9xtTOdnbxDOAtjMI0DXGARgdF/vZmpK+hlnfOBe4hF0XCMCWWO9QC2gy6IEt+V7OMtTjS"
			"VgSgb9ngfpj4F4JN71Ym1WGEmCU+No1FaV0BWudGE1FCQLOSsG0fI1yGagavA8C/OjbgzUDhuWWIIFEjQnoPkN"
			"5Fkd6R5LYVnLwsEBAlQ41F2kqlBaOFLDh4jNsJ9gVJwgT12ZuYrcCGSzK60EtRy6P7JCBy2Z9XbCmR7ptAOmpx"
			"NwcokP7I3qBgvM18baQDBz14dPUK3eGTYiRktXpLjoMRumEFuBajXS1iR1TZQJoUD3avYRG92uBq0tNLQ1FLLR"
			"rlQ6JhSHPeu7VxJWuT6rFaT7Nfvub4yytKCGBiLQOdYjNwO8vNtn6bPYNhFzZUukI2EWsPXeePzsulMg4oEa//"
			"rtni0Mye4jrtP4d4aa6LoWYsR0Ilmmy3Uz6ySW7JryrFMjfYEbBusZLe4zneiISV/MrkSliNdFxkrCbQehV6Ho"
			"ycx1VhbRtLeFC/2rBNWCsJQt6L6Et+JKBz4Q1TJpS8o1xOAzaoHtvaKCaYlGTk3cSgdTtFCQzkyKr+6No3dLIl"
			"WTVgM6cwQuqY3cE3KraCgeKUhBu4lh1O3qgQJ7bAsVBoqhV2E0CbCcwYibzg50LrvfutC7YoZP4SUtpjAn4yDh"
			"WB1L38Ar47RpCnYeUdQGaO4MHGsTk8hQG1RtMcrhjeYVcrebDuc42GXvQCSIdeo47AuwuDVF4WGPZQUEh4FfEE"
			"O2BWtrFlhOS0cx0Vmh4LTXQbVG0OrIJ6HKaJ9lDionoaJ/y0CTKOVBu/BzhOdBqmMVU4dZsgdJkZFJqg1dtg1q"
			"gT4FkC7+8IQ7bTBjqF8kaHHgaTiCFltgS3TdONasy/IkzGusB40DlmbPbaXpvjQowNfdyYuRUUDC4PWWeRy7ES"
			"3VcmyrqMbyuSJ5NYCgFKHGAtcZaKSLbTyXaxwn0nAamA8cBoI5KBzeLxBj/iT9TDuYqkgeLx6RpqhfIMGUE5w7"
			"qd0Q3tHTQxgeqwgExsjgoY0gEC26JS5oGO2dtbykrnJ5mHlGZZHC9qO3FMF2LQK2NMytPinyDdfuStgxlGpa16"
			"JvFqRevxawcQSo5EJhMTRIM3KwxcIxgNdmT2KkDsuQNlebL89yusxYvgCgY5eQzCeWHsJto0A8TnzTIoWNIkiR"
			"Y4ZqYgQ9stNUZDhqtMdkA1lgrAZy5sCRhAksCtgWwDvclsr8CsJ7Cxz57TBAqPxP1F2vPMpQqR+28HwaBgx0jz"
			"2QGZoEqbCVgKBX5eLknJdpbu2nRXGUIzDWEeU3NiJEg7EbXJIfOAdLnYgiRIBiHRt1g1DZEJDGYKBJK/loeLRm"
			"DWT5Slr6oVIkq+MIlchq3WA1CXXbpa5PiSoA";
		return p_Call_Decompress(p_s_base64, 5137, 4006, 1441);
	}

protected:
	/**
	 *	@copydoc CFTHDecompressCode_4d0633d3::p_Decode_BWT_MTF_RLE_Huff_Base64
	 */
	static inline char *p_Call_Decompress(const char *p_s_base64,
		int n_data_size, int n_huff_stage_size, uint32_t n_bwt_primary_index);
};

#ifndef __FILE_TO_HEADER_DECOMPRESS_4D0633D3_INCLUDED
#define __FILE_TO_HEADER_DECOMPRESS_4D0633D3_INCLUDED

/**
 *	@brief decompression routine implementation
 *	@note While this allows all the compressed files to share decompressor implementation,
 *		it restricts all the files to be included in a single .cpp file, otherwise linking
 *		fails because of duplicate symbols (remove body of decompress function in such case).
 */
class CFTHDecompressCode_4d0633d3 {
public:
	/**
	 *	@brief decompression routine
	 *
	 *	@param[in] p_s_base64 is null-terminated string containing BASE-64 encoded compressed data
	 *	@param[in] n_data_size is size of the decompressed data
	 *	@param[in] n_huff_stage_size is size of the compressed data before Huffman encoding
	 *	@param[in] n_bwt_primary_index is primary index for the BWT algorithm
	 *
	 *	@return Returns pointer to the decompressed data on success, 0 on failure.
	 *
	 *	@note The data (although may be binary), is additionally null terminated.
	 */
	static uint8_t *p_Decode_BWT_MTF_RLE_Huff_Base64(const char *p_s_base64,
		int n_data_size, int n_huff_stage_size, uint32_t n_bwt_primary_index)
	{
		int n_base64_length = strlen(p_s_base64);
		int n_base64_out_size = (n_base64_length / 4) * 3 +
			max(int(n_base64_length % 4) - 1, 0);

		int n_prehuff_size = max(n_base64_out_size, n_data_size);
		int n_temp_buffer_size = max(n_prehuff_size + n_huff_stage_size,
			int(n_data_size * (1 + sizeof(uint32_t))));
		uint8_t *p_temp_buffer;
		if(!(p_temp_buffer = new(std::nothrow) uint8_t[n_temp_buffer_size]))
			return 0;;
		uint8_t *p_data;
		if(!(p_data = new(std::nothrow) uint8_t[n_data_size + 1])) {
			delete[] p_temp_buffer;
			return 0;
		}
		p_data[n_data_size] = 0; // !!

		{
			int p_ic_tab[256];
			for(int i = 0; i < 256; ++ i) {
				p_ic_tab[i] = (isalpha(i))? (i | 32) - 'a' + ((i < 'a')? 0 : 26) :
					(isdigit(i))? i - '0' + 52 : (i == '+')? 62 : 63;
			}
			uint8_t *p_src = (uint8_t*)p_s_base64, *p_dst = p_temp_buffer;
			for(const uint8_t *p_end = p_src + n_base64_length - 3; p_src < p_end; p_src += 4, p_dst += 3) {
				uint8_t p_tmp[] = {p_ic_tab[p_src[1]], p_ic_tab[p_src[2]]};
				*p_dst = (p_ic_tab[p_src[0]] << 2) | (p_tmp[0] >> 4);
				p_dst[1] = (p_tmp[0] << 4) | (p_tmp[1] >> 2);
				p_dst[2] = (p_tmp[1] << 6) | p_ic_tab[p_src[3]];
			}
			if(n_base64_length % 4 == 3) {
				uint8_t n_tmp = p_ic_tab[p_src[1]];
				*p_dst = (p_ic_tab[p_src[0]] << 2) | (n_tmp >> 4);
				p_dst[1] = (n_tmp << 4) | ((p_ic_tab[p_src[2]] >> 2) & 0xf); // fixed byte order
			} else if(n_base64_length % 4 == 2)
				*p_dst = (p_ic_tab[p_src[0]] << 2) | (p_ic_tab[p_src[1]] >> 4);
		}
		{
			const uint8_t *p_huff_src = p_temp_buffer, *p_huff_end = p_huff_src + n_base64_out_size;
			_ASSERTE(p_huff_src + 16 * sizeof(int32_t) <= p_huff_end);
			const int32_t *p_code_num = (const int32_t*)p_huff_src; p_huff_src += 16 * sizeof(int32_t);
			int p_min_code[16], p_max_code[16], p_table_off[16], n_code_num = 0;
			for(int i = 0, n_cw = 0; i < 16; ++ i, n_cw <<= 1) {
				p_min_code[i] = n_cw;
				p_max_code[i] = (n_cw += p_code_num[i]);
				p_table_off[i] = n_code_num - p_min_code[i];
				n_code_num += p_code_num[i];
			}
			_ASSERTE(p_huff_src + n_code_num <= p_huff_end);
			const uint8_t *p_symbol = p_huff_src; p_huff_src += n_code_num;
			uint8_t *p_huff_dest = p_temp_buffer + n_prehuff_size;
			for(int n_byte = 0, n_bit_num = 0, n_counter = n_huff_stage_size; n_counter --;) {
				for(int i = 0, n_code = 0;; ++ i) {
					_ASSERTE(i < 16);
					if(!(n_bit_num --)) {
						_ASSERTE(p_huff_src < p_huff_end);
						n_byte = *p_huff_src ++;
						n_bit_num = 7;
					}
					n_code = (n_code << 1) | ((n_byte >> 7) & 1);
					n_byte <<= 1;
					if(n_code >= p_min_code[i] && n_code < p_max_code[i]) {
						*p_huff_dest ++ = p_symbol[n_code + p_table_off[i]];
						break;
					}
				}
			}
		}
		{
			const uint8_t *p_rle_src = p_temp_buffer + n_prehuff_size,
				*p_src_end = p_rle_src + n_huff_stage_size;
			for(uint8_t *p_rle_dest = p_temp_buffer; p_rle_src != p_src_end;) {
				uint8_t n_code = *p_rle_src ++;
				bool b_compressed = n_code & 1;
				int n_run_length = (n_code >> 1) + 1;
				_ASSERTE(p_rle_src + ((b_compressed)? 1 : n_run_length) <= p_src_end);
				while(n_run_length --)
					*p_rle_dest ++ = (b_compressed)? *p_rle_src : *p_rle_src ++;
				if(b_compressed)
					++ p_rle_src;
			}
		}
		{
			uint8_t p_buckets[256];
			for(int i = 0; i < 256; ++ i)
				p_buckets[i] = (uint8_t)i;
			const uint8_t *p_src = p_temp_buffer, *p_end = p_temp_buffer + n_data_size;
			for(; p_src != p_end; ++ p_src) {
				uint8_t *p_dest = (uint8_t*)p_src, n_index = *p_src;
				*p_dest = p_buckets[n_index];
				if(n_index) {
					for(int i = n_index; i > 0; -- i)
						p_buckets[i] = p_buckets[i - 1];
					p_buckets[0] = *p_dest;
				}
			}
		}
		{
			uint32_t p_buckets[256] = {0}, n_sum = 0;
			uint32_t *p_index_list = (uint32_t*)(p_temp_buffer + n_data_size);
			const uint8_t *p_src = p_temp_buffer, *p_end = p_temp_buffer + n_data_size;
			for(uint32_t *p_dest_idx = p_index_list; p_src != p_end; ++ p_src, ++ p_dest_idx)
				*p_dest_idx = (++ p_buckets[*p_src]) - 1;
 			for(int i = 0; i < 256; ++ i) {
				uint32_t n_value = p_buckets[i];
				p_buckets[i] = n_sum;
				n_sum += n_value;
			}
			uint8_t *p_dest = p_data + n_data_size - 1, *p_begin_1 = p_data - 1;
			for(uint32_t i = n_bwt_primary_index; p_dest != p_begin_1; -- p_dest,
			   i = p_index_list[i] + p_buckets[p_temp_buffer[i]])
				*p_dest = p_temp_buffer[i];
		}

		delete[] p_temp_buffer;
		
		return p_data;
	}
};

#endif // __FILE_TO_HEADER_DECOMPRESS_4D0633D3_INCLUDED

inline char *CIndexFile::p_Call_Decompress(const char *p_s_base64,
	int n_data_size, int n_huff_stage_size, uint32_t n_bwt_primary_index)
{
	return (char*)CFTHDecompressCode_4d0633d3::p_Decode_BWT_MTF_RLE_Huff_Base64(p_s_base64,
		n_data_size, n_huff_stage_size, n_bwt_primary_index);
}
// a dummy function that calls the decompressor, which is now declared
// (allows us to keep it at the end of the file)

#endif // __DATA_INDEX_HTML_INCLUDED
